define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ce trim.",
	"field-quarter-short-relative+1": "le trim. proch.",
	"field-tue-relative+-1": "mardi dernier",
	"field-year": "année",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"field-minute": "minute",
	"field-month-narrow-relative+-1": "le mois dernier",
	"field-tue-narrow-relative+0": "ce mar.",
	"field-tue-narrow-relative+1": "mar. prochain",
	"field-thu-short-relative+0": "ce jeu.",
	"field-day-short-relative+-1": "hier",
	"field-thu-short-relative+1": "jeu. prochain",
	"field-day-relative+0": "aujourd’hui",
	"field-day-short-relative+-2": "avant-hier",
	"field-day-relative+1": "demain",
	"field-week-narrow-relative+0": "cette semaine",
	"field-day-relative+2": "après-demain",
	"field-week-narrow-relative+1": "la semaine prochaine",
	"field-wed-narrow-relative+-1": "mer. dernier",
	"field-year-narrow": "a",
	"field-era-short": "ère",
	"field-year-narrow-relative+0": "cette année",
	"field-tue-relative+0": "ce mardi",
	"field-year-narrow-relative+1": "l’année prochaine",
	"field-tue-relative+1": "mardi prochain",
	"field-weekdayOfMonth": "jour (mois)",
	"field-second-short": "s",
	"field-weekdayOfMonth-narrow": "jour (mois)",
	"field-week-relative+0": "cette semaine",
	"field-month-relative+0": "ce mois-ci",
	"field-week-relative+1": "la semaine prochaine",
	"field-month-relative+1": "le mois prochain",
	"field-sun-narrow-relative+0": "ce dim.",
	"field-mon-short-relative+0": "ce lun.",
	"field-sun-narrow-relative+1": "dim. prochain",
	"field-mon-short-relative+1": "lun. prochain",
	"field-second-relative+0": "maintenant",
	"eraNames": [
		"avant RdC",
		"RdC"
	],
	"field-weekOfMonth": "semaine (mois)",
	"field-month-short": "m.",
	"field-day": "jour",
	"field-dayOfYear-short": "j (an)",
	"field-year-relative+-1": "l’année dernière",
	"field-sat-short-relative+-1": "sam. dernier",
	"field-hour-relative+0": "cette heure-ci",
	"field-wed-relative+-1": "mercredi dernier",
	"field-sat-narrow-relative+-1": "sam. dernier",
	"field-second": "seconde",
	"field-hour-short-relative+0": "cette h",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"field-day-narrow-relative+0": "aujourd’hui",
	"field-day-narrow-relative+1": "demain",
	"field-day-narrow-relative+2": "après-demain",
	"field-tue-short-relative+0": "ce mar.",
	"field-tue-short-relative+1": "mar. prochain",
	"field-month-short-relative+-1": "le mois dernier",
	"field-mon-relative+-1": "lundi dernier",
	"field-month": "mois",
	"field-day-narrow": "j",
	"field-minute-short": "min",
	"field-dayperiod": "cadran",
	"field-sat-short-relative+0": "ce sam.",
	"field-sat-short-relative+1": "sam. prochain",
	"eraAbbr": [
		"av. RdC",
		"RdC"
	],
	"field-second-narrow": "s",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"field-day-narrow-relative+-1": "hier",
	"field-year-short": "an",
	"field-day-narrow-relative+-2": "avant-hier",
	"field-quarter-relative+-1": "le trimestre dernier",
	"field-dayperiod-narrow": "cadran",
	"field-week-narrow-relative+-1": "la semaine dernière",
	"field-dayOfYear": "jour (année)",
	"field-sat-relative+-1": "samedi dernier",
	"field-hour": "heure",
	"field-minute-narrow-relative+0": "cette min",
	"field-month-relative+-1": "le mois dernier",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "ce sam.",
	"field-fri-relative+0": "ce vendredi",
	"field-sat-narrow-relative+1": "sam. prochain",
	"field-fri-relative+1": "vendredi prochain",
	"field-month-narrow-relative+0": "ce mois-ci",
	"field-month-narrow-relative+1": "le mois prochain",
	"field-sun-short-relative+0": "ce dim.",
	"field-sun-short-relative+1": "dim. prochain",
	"field-week-relative+-1": "la semaine dernière",
	"field-quarter-short-relative+-1": "le trim. dern.",
	"field-minute-short-relative+0": "cette min",
	"field-quarter-relative+0": "ce trimestre",
	"field-minute-relative+0": "cette minute-ci",
	"field-quarter-relative+1": "le trimestre prochain",
	"field-wed-short-relative+-1": "mer. dernier",
	"field-thu-short-relative+-1": "jeu. dernier",
	"field-year-narrow-relative+-1": "l’année dernière",
	"field-mon-narrow-relative+-1": "lun. dernier",
	"field-thu-narrow-relative+-1": "jeu. dernier",
	"field-tue-narrow-relative+-1": "mar. dernier",
	"field-weekOfMonth-short": "sem. (m.)",
	"field-wed-short-relative+0": "ce mer.",
	"field-wed-short-relative+1": "mer. prochain",
	"field-sun-relative+-1": "dimanche dernier",
	"field-weekday": "jour de la semaine",
	"field-day-short-relative+0": "aujourd’hui",
	"field-quarter-narrow-relative+0": "ce trim.",
	"field-sat-relative+0": "ce samedi",
	"field-day-short-relative+1": "demain",
	"field-quarter-narrow-relative+1": "trim. proch.",
	"field-sat-relative+1": "samedi prochain",
	"field-day-short-relative+2": "après-demain",
	"field-week-short-relative+0": "cette semaine",
	"field-week-short-relative+1": "la semaine prochaine",
	"field-dayOfYear-narrow": "j (an)",
	"field-month-short-relative+0": "ce mois-ci",
	"field-month-short-relative+1": "le mois prochain",
	"field-weekdayOfMonth-short": "jour (mois)",
	"field-zone-narrow": "fuseau horaire",
	"field-thu-narrow-relative+0": "ce jeu.",
	"field-thu-narrow-relative+1": "jeu. prochain",
	"field-sun-narrow-relative+-1": "dim. dernier",
	"field-mon-short-relative+-1": "lun. dernier",
	"field-thu-relative+0": "ce jeudi",
	"field-thu-relative+1": "jeudi prochain",
	"field-fri-short-relative+-1": "ven. dernier",
	"field-thu-relative+-1": "jeudi dernier",
	"field-week": "semaine",
	"field-wed-narrow-relative+0": "ce mer.",
	"field-wed-narrow-relative+1": "mer. prochain",
	"field-quarter-narrow-relative+-1": "trim. dern.",
	"field-year-short-relative+0": "cette année",
	"field-dayperiod-short": "cadran",
	"field-year-short-relative+1": "l’année prochaine",
	"field-fri-short-relative+0": "ce ven.",
	"field-fri-short-relative+1": "ven. prochain",
	"field-week-short-relative+-1": "la semaine dernière",
	"field-hour-narrow-relative+0": "cette h",
	"field-hour-short": "h",
	"field-zone-short": "fuseau horaire",
	"field-month-narrow": "m.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "ven. dernier",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"field-era-narrow": "ère",
	"field-fri-relative+-1": "vendredi dernier",
	"eraNarrow": [
		"av. RdC",
		"RdC"
	],
	"field-tue-short-relative+-1": "mar. dernier",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "ce lun.",
	"field-mon-narrow-relative+1": "lun. prochain",
	"field-year-short-relative+-1": "l’année dernière",
	"field-zone": "fuseau horaire",
	"field-weekOfMonth-narrow": "sem. (m.)",
	"field-weekday-narrow": "j (sem.)",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dim. dernier",
	"field-day-relative+-1": "hier",
	"field-day-relative+-2": "avant-hier",
	"field-weekday-short": "j (sem.)",
	"field-sun-relative+0": "ce dimanche",
	"field-sun-relative+1": "dimanche prochain",
	"field-day-short": "j",
	"field-week-narrow": "sem.",
	"field-era": "ère",
	"field-fri-narrow-relative+0": "ce ven.",
	"field-fri-narrow-relative+1": "ven. prochain"
}
//end v1.x content
);